@@ -66,7 +66,7 @@ class Messages:
     ]
 
 
-class TokenAction(object):
+class TokenAction:
     ACTIVATION = "activation"
     PASSWORD_RESET = "password_reset"
     ACTIVATION_SECONDARY_EMAIL = "activation_secondary_email"
