@@ -18,7 +18,7 @@ from django.db import transaction
 # gqlauth imports
 from gqlauth.settings import gqlauth_settings as app_settings
 from .constants import Messages, TokenAction
-from .utils import get_token, get_payload_from_token
+from .utils import get_token, get_payload_from_token, get_request
 from .exceptions import (
     UserAlreadyVerified,
     UserNotVerified,
@@ -33,7 +33,7 @@ USER_MODEL = get_user_model()
 
 
 class Captcha(models.Model):
-    uuid = models.UUIDField(default=uuid.uuid4, editable=False)
+    uuid = models.UUIDField(primary_key=True, default=uuid.uuid4, editable=False)
     text = models.CharField(max_length=50, editable=False)
     insert_time = models.DateTimeField(auto_now_add=True, editable=False)
     tries = models.IntegerField(default=0)
@@ -48,7 +48,7 @@ class Captcha(models.Model):
         obj = cls(text=cap.text)
         setattr(obj, "image", cap.image)
         obj.save()
-        if django_settings.DEBUG:
+        if app_settings.FORCE_SHOW_CAPTCHA:
             obj.show()
         return obj
 
@@ -83,7 +83,9 @@ class Captcha(models.Model):
             return Messages.CAPTCHA_EXPIRED
 
         # validate
-        if user_entry.replace(" ", "") == self.text.replace(" ", ""):
+        if app_settings.CAPTCHA_TEXT_VALIDATOR(
+            self.text.replace(" ", ""), user_entry.replace(" ", "")
+        ):
             # delete captcha if valid
             self.delete()
             return Messages.CAPTCHA_VALID
@@ -142,15 +144,16 @@ class UserStatus(models.Model):
 
     def get_email_context(self, info, path, action, **kwargs):
         token = get_token(self.user, action, **kwargs)
-        site = get_current_site(info.context)
+        request = get_request(info)
+        site = get_current_site(request)
         return {
             "user": self.user,
-            "request": info.context,
+            "request": request,
             "token": token,
-            "port": info.context.get_port(),
+            "port": request.get_port(),
             "site_name": site.name,
             "domain": site.domain,
-            "protocol": "https" if info.context.is_secure() else "http",
+            "protocol": "https" if request.is_secure() else "http",
             "path": path,
             "timestamp": time.time(),
             **app_settings.EMAIL_TEMPLATE_VARIABLES,
