@@ -5,7 +5,8 @@ from django.conf import settings as django_settings
 from django.contrib.auth.models import User
 from strawberry.annotation import StrawberryAnnotation
 from strawberry.utils.str_converters import to_camel_case
-from strawberry.arguments import StrawberryArgument, UNSET
+from strawberry.arguments import StrawberryArgument
+from strawberry.unset import UNSET
 from .exceptions import TokenScopeError
 
 
@@ -45,6 +46,12 @@ def list_to_dict(lst: [str]):
 warnings.simplefilter("once")
 
 
+def get_request(info):
+    if hasattr(info.context, "user"):
+        return info.context
+    return info.context.request
+
+
 def g_user(info) -> User:
     # returns a user from info obj
     user = getattr(info.context, "user", False)
